<?php
namespace DaReactions;
class AdminNotices {
    private static $api_url = 'https://www.danielealessandra.com/api/plugins/';
    private $options;
	public function __construct() {
		$this->options = Options::getInstance( 'notices' );
		$snooze_time   = $this->options->getOption( 'snooze_time', false );
		if ( ! $snooze_time ) {
			$default_date = time();
			$this->options->saveOption( 'snooze_time', $default_date );
		}
	}
	public function dismissNotice() {
		$nonce  = sanitize_text_field( $_POST['nonce'] );
		$reason = sanitize_text_field( $_POST['reason'] );
		if ( ! wp_verify_nonce( $nonce, 'da-reactions_dismiss_notice' ) ) {
			wp_send_json_error(
				array(
					'success' => 'no',
					'message' => __( 'Nonce error', 'da-reactions' )
				),
				403
			);
			exit();
		}
		switch ( $reason ) {
			case 'already-did':
				/// User don’t want to be bothered at all
				$this->options->saveOption( 'dismiss_forever', 'yes' );
				break;
			case 'snooze':
			case 'doing':
				/// User don’t want to be bothered for a month
				$this->options->setOption( 'snooze_time', time() );
				break;
			default:
				wp_send_json_error(
					array(
						'success' => 'no',
						'message' => __( 'Reason unknown', 'da-reactions' )
					),
					403
				);
				exit();
		}
	}
	public function showNotices() {
		$this->showReviewRequest();
	}
	/**
	 * Render a notice to ask customer to leave a review
	 *
	 * @since 3.16.0
	 */
	public function showReviewRequest() {
        $options = Options::getInstance('notices');
        $dismiss_forever = $options->getOption('dismiss_forever', 'no') === 'yes';
        $rating_link = 'https://wordpress.org/support/plugin/da-reactions/reviews/?rate=5#rate-response';
        $rating_site = 'WordPress.org';
        $rating_link = 'https://codecanyon.net/item/reactions-wordpress-plugin/reviews/22307601';
        $rating_site = 'CodeCanyon.net';
        if ($dismiss_forever) {
            /// User don't want to be bothered again
            return;
        }
        $snooze_time = $options->getOption('snooze_time', 204051600);
        $seconds_in_a_week = 604800;
        if (time() - (int)$snooze_time < $seconds_in_a_week) {
            /// User don't want to be bothered yet
            return;
        }
        $total_votes = Data::getReactionsCount();
        if ($total_votes < 5000) {
            /// Too soon...
            return;
        }
        $display_total_votes = Utils::formatBigNumber($total_votes);
        $image_url = DA_REACTIONS_URL . 'assets/dist/icon-256x256.png';
        $image = '<img class="da-reactions-notice-image" src="' . $image_url . '" alt="DaReactions Logo">';
        $message_title = $image . ' ' . sprintf(
                __('You got already %s reactions! Great!', 'da-reactions'),
                $display_total_votes
            );
        $message_intro = __('Positive reviews from awesome users like you help others to feel confident about choosing DaReactions too.', 'da-reactions');
        $message_request = sprintf(__('Could you take 60 seconds to go to <a href="%s" target="_blank">%s</a> and share your happy experiences?', 'da-reactions'), $rating_link, $rating_site);
        $message_greetings = __('I will be forever grateful. Thank you in advance for helping me out!', 'da-reactions');
        $registry = 'WordPress';
        $registry = 'Envato';
        ?>
        <script type="text/javascript">
            (function ($) {
                function dismiss(reason) {
                    $.ajax({
                        method: "POST",
                        dataType: "json",
                        url: ajaxurl,
                        data: {
                            action: 'da_reactions_dismiss_review_notice',
                            nonce: '<?php echo wp_create_nonce('dismiss_review_notice'); ?>',
                            reason: reason
                        }
                    });
                    <?php if ( ! empty( self::$api_url ) ) : ?>
                    $.ajax({
                        method: "POST",
                        dataType: "json",
                        url: '<?php echo self::$api_url; ?>',
                        data: {
                            plugin: "DaReactions",
                            version: "<?php echo DA_REACTIONS_VERSION; ?>",
                            registry: "<?php echo $registry; ?>",
                            action: "Dismiss notice",
                            reason: reason
                        }
                    });
                    <?php endif; ?>
                }
                $(document)
                    .on('click', '.prefix-notice .prefix-dismiss', function (event) {
                        var $this = $(this),
                            reason = $this.data('reason'),
                            notice = $this.parents('.prefix-notice');
                        notice.fadeTo(100, 0, function () {
                            notice.slideUp(100, function () {
                                notice.remove();
                            });
                        });
                        dismiss(reason);
                    });
            }(jQuery));
        </script>
        <div class="notice notice-success prefix-notice da-reactions-notice">
            <a href="#"
               class="close prefix-dismiss"
               data-reason="maybe_later">
                <i class="dashicons dashicons-no" title="<?php _e('Close', 'da-reactions'); ?>"></i>
                <?php _e('Nope, maybe later', 'da-reactions'); ?>
            </a>
            <div class="notice-body">
                <h4><?php echo $message_title; ?></h4>
                <p><?php echo $message_intro; ?>
                    <?php echo $message_request; ?></p>
                <p><?php echo $message_greetings; ?></p>
            </div>
            <ul>
                <li>
                    <a href="#"
                       class="button button-secondary prefix-dismiss"
                       data-reason="already_did">
                        <?php _e('I already did', 'da-reactions'); ?>
                    </a>
                </li>
                <li>
                    <a class="button button-primary prefix-dismiss"
                       target="_blank"
                       href="<?php echo $rating_link; ?>"
                       data-reason="am_now">
                        <strong><?php _e('Ok, you deserve it', 'da-reactions'); ?></strong>
                    </a>
                </li>
            </ul>
        </div>
        <?php
	}
}
